==> camunda-engine-7.2.0-alpha4-sources.jar: org/camunda/bpm/engine/impl/cmmn/operation/AtomicOperationCaseExecutionReactivate.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.cmmn.operation;

import static org.camunda.bpm.engine.delegate.CaseExecutionListener.RE_ACTIVATE;
import static org.camunda.bpm.engine.impl.cmmn.execution.CaseExecutionState.ACTIVE;

import org.camunda.bpm.engine.impl.cmmn.behavior.CmmnActivityBehavior;
import org.camunda.bpm.engine.impl.cmmn.execution.CmmnExecution;
import org.camunda.bpm.engine.impl.pvm.PvmException;

/**
 * @author Roman Smirnov
 *
 */
public class AtomicOperationCaseExecutionReactivate extends AbstractCmmnEventAtomicOperation {

  public String getCanonicalName() {
    return "case-execution-re-activate";
  }

  protected String getEventName() {
    return RE_ACTIVATE;
  }

  protected CmmnExecution eventNotificationsStarted(CmmnExecution execution) {
    try {
      CmmnActivityBehavior behavior = getActivityBehavior(execution);
      behavior.onReactivation(execution);

      execution.setCurrentState(ACTIVE);

    } catch (RuntimeException e) {
      String id = execution.getId();
      throw new PvmException("Cannot re-activate case execution '"+id+"'.", e);
    }


    return execution;
  }

  protected void eventNotificationsCompleted(CmmnExecution execution) {
    CmmnActivityBehavior behavior = getActivityBehavior(execution);
    behavior.reactivated(execution);
  }

}

==> camunda-engine-7.3.0-alpha4-sources.jar: org/camunda/bpm/engine/impl/cmmn/operation/AtomicOperationCaseExecutionReactivate.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.cmmn.operation;

import static org.camunda.bpm.engine.delegate.CaseExecutionListener.RE_ACTIVATE;
import static org.camunda.bpm.engine.impl.cmmn.execution.CaseExecutionState.ACTIVE;
import static org.camunda.bpm.engine.impl.util.ActivityBehaviorUtil.getActivityBehavior;

import org.camunda.bpm.engine.impl.cmmn.behavior.CmmnActivityBehavior;
import org.camunda.bpm.engine.impl.cmmn.execution.CmmnExecution;

/**
 * @author Roman Smirnov
 *
 */
public class AtomicOperationCaseExecutionReactivate extends AbstractCmmnEventAtomicOperation {

  public String getCanonicalName() {
    return "case-execution-re-activate";
  }

  protected String getEventName() {
    return RE_ACTIVATE;
  }

  protected CmmnExecution eventNotificationsStarted(CmmnExecution execution) {
    CmmnActivityBehavior behavior = getActivityBehavior(execution);
    behavior.onReactivation(execution);

    execution.setCurrentState(ACTIVE);

    return execution;
  }

  protected void postTransitionNotification(CmmnExecution execution) {
    CmmnActivityBehavior behavior = getActivityBehavior(execution);
    behavior.reactivated(execution);
  }

}
